@@ -14,6 +14,7 @@
 local_signal <- function(N, A=1, Fr=1, phase=0, S=0, L=N) {
   periodic_signal <- cosine(N, A=A, Fr=Fr, phase=phase)
 
+  ## Indicator, adjusting for the fact the math notation uses a 0-index
   indicator <- rep(0, N)
   indicator[(S + 1):(S + L)] <- 1
 
@@ -40,12 +41,12 @@ prou <- function(n) {
 #' @param Fr Frequency: Number of cycles in a length N period
 #' @param phase phase
 #'
+#' @export
+#'
 #' @return numeric vector with cosine function of x
 #'
 cosine <- function(N, A=1, Fr=1, phase=0) {
-  x <- 0:(N - 1)
-  A * cos( ((2 * pi * Fr * x) / N) + phase )
-
+  A * cos( (2 * pi * Fr * (0:(N - 1)) ) + phase )
 }
 
 #' Sine signal with adjustable parameters
@@ -55,9 +56,10 @@ cosine <- function(N, A=1, Fr=1, phase=0) {
 #' @param Fr Frequency: Number of cycles in a length N period
 #' @param phase phase
 #'
+#' @export
+#'
 #' @return numeric vector with sine
 #'
 sine <- function(N, A=1, Fr=1, phase=0) {
-  x <- 0:(N - 1)
-  A * sin( ((2 * pi * Fr * x) / N) + phase )
+  A * sin( (2 * pi * Fr * (0:(N - 1)) ) + phase )
 }
